function[R,ERvec]=microport(n,Rmat,ERmat,Cmat,SGmat);
%this program forms the cross-section of micro portfolios using the
%procedure described in Section II.B of the paper

%output:
%R is the TxM matrix of micro portfolio returns (T is the
%number of observations and M is the total number of micro portfolios)
%ER is the Tx1 vector of estimated average portfolio returns

%inputs:
%n is the number of stocks included in the portfolios
%Rmat is the TxN matrix of stock returns (T is the
%number of observations and N is the total number of assets)
%ERmat is the TxN matrix of estimated average returns 
%Cmat is the TxN matrix of indicators which indicates whether the asset is
%classified as common stock
%belong to the examined size group
%SGmat is the TxN matrix of indicators which indicates whether the asset
%belong to the examined size group


%Note: the (t,i)-element of ERmat is computed as a linear combination of
%the recent characteristics at time t; the coefficients are obtained by running 
%cross-sectional Fama-McBeth regressions over the periods prior to time t

T=size(ERmat,1);
N=size(ERmat,2);
nbyear=ceil(size(ERmat)/12);
idstock=[1:1:N];
for j=1:nbyear,
    j
    b1=1+(j-1)*12;
    %if the final year is not complete
    if j*12>T;
        b2=size(Rmat,1); 
    else
        b2=j*12;
    end
    indicb=find(ERmat(b1,:)~=-999 & Cmat(b1,:)==1 & SGmat(b1,:)==1);
    Ry=Rmat(b1:b2,indicb);
    ERy=ERmat(b1:b2,indicb);
    idstocky=idstock(1,indicb); 
    % we form the micro portfolios using localaveraging  
    [Rmpy,ERmpy,ERys]=localaveraging(n,Ry,ERy);
     if j==1,
         R=Rmpy;
         ER=ERmpy;
         Nmp=size(R,2);
         ERysold=ERys;
         idstockyold=idstocky;
         idmpold=[1:1:Nmp];
     else
         %we now match the micro portfolios
         [Rmpy,ERmpy,ERysold,idstockyold,idmpold]=timeaveraging(Rmpy,ERmpy,ERys,idstocky,ERysold,idstockyold,idmpold);
         %now we chain the returns across years
         My=size(Rmpy,2);
         Mt=size(R,2);
         Tt=size(R,1);
         add=max(0,My-Mt);
         R=[R,-999*ones(Tt,add)];
         R=[R;Rmpy];
         ER=[ER,-999*ones(Tt,add)];
         ER=[ER;ERmpy];
     end
end
[ERvec]=standard(ER);