function[propvec,stdvec,fp,lambdaB,pe,a,b]=perfeval(ExcR,ERvec,F,Fo,mindata,interval,nbtraded,lag)
%this program evaluates the performance of the models using the large-scale
%approach described in Section II.B of the paper

%output:
%propvec is the 3x1 vector that contains the proportion of mispriced 
%portfolios, the porportions of portfolios with negative pricing errors,
%and the proportions of portfolios with positive pricing errors
%stdvec is the 3x1 vector of volatilities for the proportions in propvec
%nuB is the vector of forward prices for the non-traded factors
%lambda is the Jx1 vector of factor risk premia
%pe is the Mx1 vector of pricing errors
%a is the Mx1 vector of intercept in the first pass-regression
%b is the MxJ vector of betas in the first pass-regression

%inputs:
%ExcRmat is the TxMo matrix of original excess portfolio returns (before
%any trimming), where Mo denotes the total number of portfolios)
%ERvec is the Mox1 vector of estimated average portfolio returns
%F is the TxJ matrix of factors (including the constant) included in 
%the model where the traded factors are ordered first
%Fo is the TxP matrix of the factors included in the other tested models
%(which are orthogonal to F)
%mindata is the minumum number of return observations for trimming (60
%monthly observations in the baseline case)
%nbtraded is the number of traded factors in the model
%lag is the number of lags to compute the proportion volatilites

Ti=sum(ExcR~=-999,1)';
I=(ExcR~=-999);

%extended two-pass regression
[a,br,Vr,nuB,Ti,ERvec,lambdaB,b]=twopass(ExcR,F,Fo,I,Ti,ERvec,mindata,nbtraded);                                                                               

%computation of the tstatistics of the pricing errors
[tstatpe,pe]=tstatpecomp(a,br,nuB,Vr,Ti);
fp=-nuB;

%computation of the mispricing proportion and volatilities
[propvec,stdvec]=mispricingproportion(tstatpe,ERvec,interval,lag);